"use client";

import React, { useEffect, useState } from 'react';
import Web3 from 'web3';
import { Container, Typography, List, ListItem, Paper, Grid } from '@mui/material';
import NavBar from '../components/NavBar';
import { useRouter } from 'next/navigation';

import { checkConnectionMetaMask,  contract } from '../utils';

const AuctionList = () => {
    const [auctions, setAuctions] = useState([]);
    const { auctionContract, web3 } = contract();
    const router = useRouter();

    useEffect(() => {
        const fetchItemsAvailable = async () => {
            const accounts = await checkConnectionMetaMask();
            if (accounts.length === 0) {
                router.push('/');
            }
            else {
                const getAuctions = async () => {
                    try {
                        const availableAuctions = await auctionContract.methods.getAllAuctionItems().call();
                        console.log('Available Auctions:', availableAuctions);

                        setAuctions(availableAuctions);
                    } catch (error) {
                        console.error('Error fetching available auctions:', error);
                        setAuctions([]);
                    }
                };

                getAuctions();
            }
        };

        fetchItemsAvailable();
    }, []);

    return (
        <>
            <NavBar />
            <Container>
                <Typography variant="h2">Liste des Enchères Disponibles</Typography>
                <Paper elevation={3}>
                    <List>
                        {auctions.map((auction, index) => (
                            <ListItem key={index}>
                                <Typography variant="subtitle1">Item {index + 1}:</Typography>
                                <Typography variant="body1">Prix: {web3.utils.fromWei(auction.toString(), 'ether')} Ether</Typography>
                            </ListItem>
                        ))}
                    </List>
                </Paper>
            </Container>
        </>
    );
};

export default AuctionList;
